OMS-GALLERY
=================

A image management and gallery application for the Django web framework. Upload photos, upload photos zip-achieve, group them into galleries.

Install
--------
::

    pip install oms_gallery

    INSTALLED_APPS = [
    
        'oms-gallery',
    ]
    
    python manage.py migrate